@@ -32,10 +32,14 @@ from tacker.common import utils
 from tacker.objects import fields
 from tacker.tests.functional import base
 from tacker.tests.functional.base import BaseTackerTest
+from tacker.tests.functional.common import logging_utils
 from tacker.tests.functional.sol.vnflcm import base as vnflcm_base
 from tacker.tests.functional.sol.vnflcm import fake_vnflcm
 from tacker.tests.utils import _update_unique_id_in_yaml
 from tacker.tests.utils import read_file
+from tacker.tests.utils import test_etc_sample
+
+LOG = logging_utils.get_logger(__name__)
 
 
 class BaseEnhancedPolicyTest(object):
@@ -520,12 +524,7 @@ class BaseEnhancedPolicyTest(object):
 
     @classmethod
     def _get_csar_dir_path(cls, csar_name):
-        csar_dir = os.path.abspath(
-            os.path.join(os.path.dirname(__file__),
-            "../../etc/samples/etsi/nfv",
-            csar_name))
-
-        return csar_dir
+        return test_etc_sample("etsi/nfv", csar_name)
 
     @classmethod
     def _glance_client(cls, username=None, tenant=None):
@@ -547,10 +546,8 @@ class BaseEnhancedPolicyTest(object):
         else:
             raise Exception('vim_user_project_map is needed.')
         image_name = "cirros-0.5.2-x86_64-disk"
-        image_path = os.path.abspath(
-            os.path.join(os.path.dirname(__file__),
-            "../../etc/samples/etsi/nfv/common/Files/images",
-            f"{image_name}.img"))
+        image_path = test_etc_sample("etsi/nfv/common/Files/images",
+                                     f"{image_name}.img")
         image_data = {
             'disk_format': 'qcow2',
             'container_format': 'bare',
@@ -769,6 +766,36 @@ class VimAPIsTest(BaseTackerTest, BaseEnhancedPolicyTest):
         # step 9 VIM-Delete, Resource Group C / User Group admin
         self._step_vim_delete('user_admin', vim_c, 204)
 
+    def _test_vim_apis_enhanced_policy_special_role(self, vim_type, local_vim):
+        # step 1 VIM-Register, Area special role / User Group A
+        vim_a_1 = self._step_vim_register(
+            'user_a', vim_type, local_vim, 'vim_a_1', 'all@region_A', 201)
+
+        # step 2 VIM-Register, Area special role / User Group A
+        vim_a_2 = self._step_vim_register(
+            'user_a', vim_type, local_vim, 'vim_a_2', 'all@all', 201)
+
+        # step 3 VIM-Show, Area special role / User Group A
+        self._step_vim_show('user_a', vim_a_1, 404)
+
+        # step 4 VIM-Show, Area special role / User Group A
+        self._step_vim_show('user_a', vim_a_2, 404)
+
+        # step 5 VIM-Show, Area special role / User Group All
+        self._step_vim_show('user_all', vim_a_1, 200)
+
+        # step 6 VIM-Show, Area special role / User Group Admin
+        self._step_vim_show('user_admin', vim_a_2, 200)
+
+        # step 7 VIM-Delete, Area special role / User Group A
+        self._step_vim_delete('user_a', vim_a_1, 404)
+
+        # step 8 VIM-Delete, Area special role / User Group All
+        self._step_vim_delete('user_all', vim_a_1, 204)
+
+        # step 9 VIM-Delete, Area special role / User Group Admin
+        self._step_vim_delete('user_admin', vim_a_2, 204)
+
 
 class VnflcmAPIsV1Base(vnflcm_base.BaseVnfLcmTest, BaseEnhancedPolicyTest):
 
@@ -910,14 +937,11 @@ class VnflcmAPIsV1Base(vnflcm_base.BaseVnfLcmTest, BaseEnhancedPolicyTest):
             vnf_lcm_op_occ_id = None
             notify_mock_responses = fake_server_manager.get_history(
                 callback_url)
-            print(
-                ("Wait:callback_url=<%s>, "
-                "wait_operation=<%s>, "
-                "wait_status=<%s>, "
-                "vnf_instance_id=<%s>") %
-                (callback_url, operation, expected_operation_status,
-                 vnf_instance_id),
-                flush=True)
+            LOG.debug("Waiting lcm done: %s=%s, %s=%s, %s=%s, %s=%s" %
+                ('callback_url', callback_url,
+                 'wait_operation', operation,
+                 'wait_status', expected_operation_status,
+                 'vnf_instance_id', vnf_instance_id))
 
             for res in notify_mock_responses:
                 if (vnf_instance_id != res.request_body.get('vnfInstanceId')
